import { Link, useParams } from 'react-router-dom'

import Page from 'components/page'
import { useTranslation } from 'react-i18next'
import {
  Button,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Paper,
} from '@mui/material'
import { Guest, Role } from 'interfaces'
import SponsorInfoButtons from 'routes/components/sponsorInfoButtons'
import { format } from 'date-fns'

type GuestInfoParams = {
  pid: string
}
interface RoleLineProps {
  role: Role
  pid: string
}
type GuestInfoProps = {
  guest: Guest
  roles: Role[]
}

const RoleLine = ({ role, pid }: RoleLineProps) => {
  const [t, i18n] = useTranslation('common')
  return (
    <TableRow sx={{ '&:last-child td, &:last-child th': { border: 0 } }}>
      <TableCell align="left">
        {i18n.language === 'en' ? role.name_en : role.name_nb}
      </TableCell>
      <TableCell component="th" scope="row">
        {role.start_date ? format(role.start_date, 'yyyy-MM-dd') : null} -{' '}
        {format(role.end_date, 'yyyy-MM-dd')}
      </TableCell>
      <TableCell align="left">
        {i18n.language === 'en' ? role.ou_en : role.ou_nb}
      </TableCell>
      <TableCell>
        <Button
          variant="contained"
          component={Link}
          to={`/sponsor/guest/${pid}/roles/${role.id}`}
        >
          {t('sponsor.choose')}
        </Button>
      </TableCell>
    </TableRow>
  )
}

export default function GuestInfo({ guest, roles }: GuestInfoProps) {
  const { pid } = useParams<GuestInfoParams>()
  const [t] = useTranslation(['common'])

  return (
    <Page>
      <SponsorInfoButtons to="/sponsor" name={`${guest.first} ${guest.last}`} />
      <h4>{t('guestInfo.contactInfo')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('guestInfo.contactInfo')}</TableCell>
              <TableCell />
            </TableRow>
          </TableHead>
          <TableBody>
            <TableRow>
              <TableCell align="left">{t('input.fullName')}</TableCell>
              <TableCell align="left">
                {`${guest.first} ${guest.last}`}
              </TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.email')}</TableCell>
              <TableCell align="left">{guest.email}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.nationalIdNumber')}</TableCell>
              <TableCell align="left">{guest.fnr}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.mobilePhone')}</TableCell>
              <TableCell align="left">{guest.mobile}</TableCell>
            </TableRow>
          </TableBody>
        </Table>
      </TableContainer>
      <h4>{t('guestInfo.roleInfoHead')}</h4>
      <h5>
        {t('guestInfo.roleInfoBody')}
        <Button
          variant="contained"
          component={Link}
          to={`/sponsor/guest/${pid}/newrole`}
        >
          {t('sponsor.addRole')}
        </Button>
      </h5>

      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('common:role')}</TableCell>
              <TableCell align="left">{t('common:period')}</TableCell>
              <TableCell align="left">{t('common:ou')}</TableCell>
              <TableCell align="left">{t('common:choice')}</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {roles.map((role) => (
              <RoleLine key={role.id} pid={pid} role={role} />
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </Page>
  )
}
