import { FetchedRole, Guest, Role } from 'interfaces'
import { useEffect, useState } from 'react'
import { Route, useParams } from 'react-router-dom'
import { parseRole } from 'utils'
import GuestInfo from './guestInfo'
import GuestRoleInfo from './guestRoleInfo'
import NewGuestRole from './newGuestRole'

type GuestInfoParams = {
  pid: string
}

function GuestRoutes() {
  const { pid } = useParams<GuestInfoParams>()

  const [guestInfo, setGuest] = useState<Guest>({
    pid: '',
    first: '',
    last: '',
    email: '',
    fnr: '',
    mobile: '',
    active: false,
    registered: false,
    verified: false,
    roles: [],
  })
  const [roles, setRoles] = useState<Role[]>([])

  const getPerson = async (id: string) => {
    try {
      const response = await fetch(`/api/ui/v1/person/${id}`)
      const rjson = await response.json()
      if (response.ok) {
        setGuest({
          pid: rjson.pid,
          first: rjson.first,
          last: rjson.last,
          email: rjson.email,
          mobile: rjson.mobile,
          fnr: rjson.fnr,
          active: rjson.active,
          registered: rjson.registered,
          verified: rjson.verified,
          roles: rjson.roles,
        })
        setRoles(rjson.roles.map((role: FetchedRole) => parseRole(role)))
      }
    } catch (error) {
      console.error(error)
    }
  }

  useEffect(() => {
    getPerson(pid)
  }, [])

  return (
    <>
      <Route path="/sponsor/guest/:pid/roles/:id">
        <GuestRoleInfo guest={guestInfo} roles={roles} />
      </Route>
      <Route exact path="/sponsor/guest/:pid/newrole">
        <NewGuestRole guest={guestInfo} />
      </Route>
      <Route exact path="/sponsor/guest/:pid">
        <GuestInfo guest={guestInfo} roles={roles} />
      </Route>
    </>
  )
}

export default GuestRoutes
