import { useEffect, useState } from 'react'
import { Route } from 'react-router-dom'

import FrontPage from 'routes/sponsor/frontpage'
import { FetchedGuest, Guest } from 'interfaces'
import { parseRole, submitJsonOpts } from 'utils'
import GuestRoutes from './guest'

function Sponsor() {
  const [guests, setGuests] = useState<Guest[]>([])

  const getGuestsInfo = async () => {
    try {
      const response = await fetch('/api/ui/v1/guests/?format=json')
      const jsonResponse = await response.json()
      if (response.ok) {
        const persons = await jsonResponse.persons
        setGuests(
          persons.map(
            (person: FetchedGuest): Guest => ({
              pid: person.pid,
              first: person.first,
              last: person.last,
              email: person.email,
              mobile: person.mobile,
              fnr: person.fnr,
              active: person.active,
              roles: person.roles.map((role) => parseRole(role)),
              registered: person.registered,
              verified: person.verified,
            })
          )
        )
      }
    } catch (error) {
      setGuests([])
    }
  }

  const cancelRole = (roleId: string) => {
    // There is no body for this request, but using submitJsonOpts still to
    // set the CSRF-token
    fetch(`/api/ui/v1/invite/?role_id=${roleId}`, submitJsonOpts('DELETE', {}))
      .then((res) => {
        if (!res.ok) {
          return null
        }
        return res.text()
      })
      .then((result) => {
        if (result !== null) {
          // The invitation has been removed. Just reload all the data form the server to get updated data.
          // The guests state will be updated by getGuestsInfo and this will trigger a rerender
          getGuestsInfo()
        }
      })
      .catch((error) => {
        // TODO User should get some feedback telling him something failed
        console.log('error', error)
      })
  }

  useEffect(() => {
    getGuestsInfo()
  }, [])

  return (
    <>
      <Route path="/sponsor/guest/:pid">
        <GuestRoutes />
      </Route>
      <Route exact path="/sponsor">
        <FrontPage guests={guests} cancelRole={cancelRole} />
      </Route>
    </>
  )
}

export default Sponsor
